package collector

import (
	"testing"
)

func TestMetricStringCleanup(t *testing.T) {
	// Test case 1: String with hyphens
	input := "example-metric-name"
	expected := "example_metric_name"
	result := metricStringCleanup(input)
	if result != expected {
		t.Errorf("Expected '%s', but got: '%s'", expected, result)
	}

	// Test case 2: String without hyphens
	input = "example_metric_name"
	expected = "example_metric_name"
	result = metricStringCleanup(input)
	if result != expected {
		t.Errorf("Expected '%s', but got: '%s'", expected, result)
	}

	// Test case 3: Empty string
	input = ""
	expected = ""
	result = metricStringCleanup(input)
	if result != expected {
		t.Errorf("Expected empty string, but got: '%s'", result)
	}
}

func TestDescriptionForPropertyName(t *testing.T) {
	// Test case 1: Basic test case
	prefix := "prefix"
	property := "property"
	labelNames := []string{"label1", "label2"}
	desc := descriptionForPropertyName(prefix, property, labelNames)
	expectedName := "Desc{fqName: \"arvancloud_prefix_property\", help: \"property\", constLabels: {}, variableLabels: {label1,label2}}"
	if desc.String() != expectedName {
		t.Errorf("Expected description name '%s', but got: '%s'", expectedName, desc.String())
	}
}

func TestDescriptionForPropertyNameHelpText(t *testing.T) {
	// Test case 1: Basic test case
	prefix := "prefix"
	property := "property"
	labelNames := []string{"label1", "label2"}
	helpText := "help_text"
	desc := descriptionForPropertyNameHelpText(prefix, property, labelNames, helpText)
	expectedName := "Desc{fqName: \"arvancloud_prefix_property\", help: \"help_text\", constLabels: {}, variableLabels: {label1,label2}}"
	if desc.String() != expectedName {
		t.Errorf("Expected description name '%s', but got: '%s'", expectedName, desc.String())
	}

	// Test case 2: Empty help text
	prefix = "prefix"
	property = "property"
	labelNames = []string{"label1", "label2"}
	helpText = ""
	desc = descriptionForPropertyNameHelpText(prefix, property, labelNames, helpText)
	expectedName = "Desc{fqName: \"arvancloud_prefix_property\", help: \"\", constLabels: {}, variableLabels: {label1,label2}}"
	if desc.String() != expectedName {
		t.Errorf("Expected description name '%s', but got: '%s'", expectedName, desc.String())
	}
}

func TestDescription(t *testing.T) {
	// Test case 1: Basic test case
	prefix := "prefix"
	name := "name"
	labelNames := []string{"label1", "label2"}
	helpText := "help_text"
	desc := description(prefix, name, helpText, labelNames)
	expectedName := "Desc{fqName: \"arvancloud_prefix_name\", help: \"help_text\", constLabels: {}, variableLabels: {label1,label2}}"
	if desc.String() != expectedName {
		t.Errorf("Expected description name '%s', but got: '%s'", expectedName, desc.String())
	}
}

func TestAvgOfArray(t *testing.T) {
	// Test case 1: Calculate average of an array
	data := []float64{1.0, 2.0, 3.0, 4.0, 5.0}
	average := avgOfArray(data)
	expected := 3.0 // (1+2+3+4+5) / 5 = 3.0
	if average != expected {
		t.Errorf("Expected average to be %f, but got %f", expected, average)
	}

	// Test case 2: Empty array
	emptyData := []float64{}
	average = avgOfArray(emptyData)
	expected = 0.0 // Average of an empty array is 0.0
	if average != expected {
		t.Errorf("Expected average of an empty array to be %f, but got %f", expected, average)
	}
}
