package config

import (
	"io"

	yaml "gopkg.in/yaml.v2"
)

// Config represents the configuration for the exporter
type Config struct {
	Token    string `yaml:"token"`
	Products struct {
		CDN struct {
			Enabled bool     `yaml:"enable,omitempty"`
			Domains []string `yaml:"domains,omitempty"`
			Period  string   `yaml:"period,omitempty"`
		} `yaml:"cdn,omitempty"`
		OBJECT struct {
			Enabled bool     `yaml:"enable,omitempty"`
			Buckets []string `yaml:"buckets,omitempty"`
		} `yaml:"object,omitempty"`
	} `yaml:"products,omitempty"`
}

// Load reads YAML from reader and unmarshal in Config
func Load(r io.Reader) (*Config, error) {
	b, err := io.ReadAll(r)
	if err != nil {
		return nil, err
	}

	c := &Config{}
	err = yaml.Unmarshal(b, c)
	if err != nil {
		return nil, err
	}

	return c, nil
}

// EnabledProducts returns a comma separated string of enabled products
func (c *Config) EnabledProducts() string {
	var enabledProducts []string

	if c.Products.CDN.Enabled {
		enabledProducts = append(enabledProducts, "CDN")
	}

	if c.Products.OBJECT.Enabled {
		enabledProducts = append(enabledProducts, "OBJECT")
	}

	return joinStrings(enabledProducts, ", ")
}

func joinStrings(strs []string, sep string) string {
	if len(strs) == 0 {
		return ""
	}

	result := strs[0]
	for _, str := range strs[1:] {
		result += sep + str
	}

	return result
}
